"use strict";
var _a, _b;
Object.defineProperty(exports, "__esModule", { value: true });
exports.filename = void 0;
const upath_1 = require("@ewizardjs/upath");
const webpack_merge_1 = require("webpack-merge");
const rules_1 = require("@ewizardjs/builder-utils/rules");
const plugins_1 = require("../plugins");
const utils_1 = require("../utils");
const PLUGINS_TO_REMOVE = [
    'CleanWebpackPlugin',
    'ValidateContentPathsPlugin',
    'WebpackBarPlugin',
];
const RULES_TO_REMOVE = [
    (_a = (0, rules_1.images)({ options: {} }).test) === null || _a === void 0 ? void 0 : _a.toString(),
    (_b = (0, rules_1.media)({ options: {} }).test) === null || _b === void 0 ? void 0 : _b.toString(),
];
const addPublicPath = (p) => {
    return `(window.__publicPath || '') + ${p}`;
};
exports.filename = 'build/dev/components-list.js';
exports.default = (presentationPath, config) => {
    const componentsListConfig = getComponentsListConfig(presentationPath);
    const ComponentsLibraryConfig = (0, webpack_merge_1.mergeWithCustomize)({
        customizeArray(item1, item2, key) {
            if (key === 'plugins') {
                const defaultPlugins = item1;
                const templatesPlugins = item2;
                return (0, utils_1.removePlugins)(defaultPlugins, PLUGINS_TO_REMOVE).concat(templatesPlugins);
            }
            if (key === 'module.rules') {
                const defaultRules = item1;
                const templatesRules = item2;
                return (0, utils_1.removeRules)(defaultRules, RULES_TO_REMOVE).concat(templatesRules);
            }
        },
    })(config, componentsListConfig);
    return [ComponentsLibraryConfig, config];
};
function getComponentsListConfig(presentationPath) {
    return {
        entry: require.resolve('../../assets/components-list.js'),
        mode: 'production',
        devtool: false,
        output: {
            filename: exports.filename,
            library: 'ComponentsList',
            libraryTarget: 'window',
        },
        performance: {
            hints: false,
        },
        module: {
            rules: [
                (0, rules_1.images)({
                    options: {
                        emitFile: false,
                        postTransformPublicPath: addPublicPath,
                        useRequire: false,
                    },
                }),
                (0, rules_1.media)({
                    options: {
                        emitFile: false,
                        postTransformPublicPath: addPublicPath,
                    },
                }),
                {
                    test: /template\.vue$/i,
                    use: [{
                            loader: require.resolve('../loaders/vue-component-to-module-loader'),
                        }],
                },
            ],
        },
        plugins: [
            (0, plugins_1.cleanDestinationFolder)([(0, upath_1.join)(presentationPath, exports.filename)]),
            new plugins_1.InjectComponentsListToHtmlPlugin(presentationPath),
        ],
    };
}
//# sourceMappingURL=webpack.config.js.map